# Bopku

Bopku merupakan alat bantu administrasi BOP Paud.

## Fitur yang akan datang

Berikut fitur yang akan direncanakan untuk aplikasi ini.

- Export ke excel
- Export ke word
- Print Kwitansi

## Donasi

Jika anda ingin melakukan donasi untuk kami, bisa menghubungi kami melalui [WhatsApp](https://wa.me/6287725780404) ataupun [Telegram](https://t.me/hexatester).

## Legal / Hukum

Kode ini sama sekali tidak berafiliasi dengan, diizinkan, dipelihara, disponsori atau didukung oleh Kemdikbud atau afiliasi atau anak organisasinya. Ini adalah perangkat lunak yang independen dan tidak resmi. _Gunakan dengan risiko Anda sendiri_.
